@@ -43,14 +43,16 @@ class StandardAPIView(BaseAPIView):
             paginated_data = serializer.data
 
         # Include the count, next, and previous fields in the response
-        response = paginator.get_paginated_response(paginated_data)
-        response['success'] = True
-        response['count'] = paginator.count
-        response['next'] = paginator.get_next_link()
-        response['previous'] = paginator.get_previous_link()
-        response['status'] = status.HTTP_200_OK
+        response = {
+            'success': True,
+            'status': status.HTTP_200_OK,
+            'count': paginator.count,
+            'next': paginator.get_next_link(),
+            'previous': paginator.get_previous_link(),
+            'data': paginated_data,
+        }
 
-        return response
+        return APIResponseSerializer(response, context=context).data
 
 
 # ============= Demo Views ============= #
